/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.Vector;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.ReferenceArray;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Klasse realisiert den WVZ-Inhalt einer Anzeige
 * @author Swarco Traffic Systems GmbH
 * @author Matthias Obert
 */
public class WVZInhalt
{
  /**
   * Objekt mit dem Anzeigeninhalt
   */
  private SystemObject m_anzeigenInhalt;
  
  /**
   * Blinken
   */
  private boolean m_blinken = false;
  
  /**
   * Blinktakt
   */
  private float m_blinkTakt = 0;
  
  /**
   * Grafikdarstellungen
   */
  private Vector<SystemObject> m_grafikDarstellungen = new Vector<SystemObject>();
  
  /**
   * Wechseltext
   */
  private SystemObject m_wechselText;
  
  /**
   * Dynamischer Wechseltext
   */
  private DynamischerWechselText m_dynamischerWechselText = new DynamischerWechselText ();

  /**
   * Prioritt Anzeigeninhalt.
   */
  private int m_prioritaet = -1;
  
  /**
   * Datensatz Wvzinhalt.
   */
  private Data m_wvzInhalt;
  
  /**
   * Methode liefert die Variable m_anzeigenInhalt zurck
   * @return Variable m_anzeigenInhalt
   */
  public SystemObject getAnzeigenInhalt()
  {
    return m_anzeigenInhalt;
  }

  /**
   * Methode setzt die Variable m_anzeigenInhalt
   * @param anzeigenInhalt Wert auf den die Variable m_anzeigenInhalt gesetzt werden soll
   */
  public void setAnzeigenInhalt( SystemObject anzeigenInhalt )
  {
    m_anzeigenInhalt = anzeigenInhalt;
  }

  /**
   * Methode liefert die Variable m_blinken zurck
   * @return Variable m_blinken
   */
  public boolean isBlinken()
  {
    return m_blinken;
  }

  /**
   * Methode setzt die Variable m_blinken
   * @param blinken Wert auf den die Variable m_blinken gesetzt werden soll
   */
  public void setBlinken( boolean blinken )
  {
    m_blinken = blinken;
  }

  /**
   * Methode liefert die Variable m_blinkTakt zurck
   * @return Variable m_blinkTakt
   */
  public float getBlinkTakt()
  {
    return m_blinkTakt;
  }

  /**
   * Methode setzt die Variable m_blinkTakt
   * @param blinkTakt Wert auf den die Variable m_blinkTakt gesetzt werden soll
   */
  public void setBlinkTakt( float blinkTakt )
  {
    m_blinkTakt = blinkTakt;
  }

  /**
   * Methode liefert die Variable m_grafikDarstellungen zurck
   * @return Variable m_grafikDarstellungen
   */
  public Vector<SystemObject> getGrafikDarstellungen()
  {
    Vector<SystemObject> v = new Vector<SystemObject>();
    
    synchronized (m_grafikDarstellungen)
    {
      for (SystemObject o : m_grafikDarstellungen)
        v.add( o );
    }
    return v;
  }

  /**
   * Methode setzt die Variable m_grafikDarstellungen
   * @param grafikDarstellungen Wert auf den die Variable m_grafikDarstellungen gesetzt werden soll
   */
  public void setGrafikDarstellungen( Vector<SystemObject> grafikDarstellungen )
  {
    synchronized (m_grafikDarstellungen)
    {
      m_grafikDarstellungen = grafikDarstellungen;
    }
  }

  /**
   * Methode liefert die Variable m_wechselText zurck
   * @return Variable m_wechselText
   */
  public SystemObject getWechselText()
  {
    return m_wechselText;
  }

  /**
   * Methode setzt die Variable m_wechselText
   * @param wechselText Wert auf den die Variable m_wechselText gesetzt werden soll
   */
  public void setWechselText( SystemObject wechselText )
  {
    m_wechselText = wechselText;
  }

  /**
   * Methode liefert die Variable m_dynamischerWechselText zurck
   * @return Variable m_dynamischerWechselText
   */
  public DynamischerWechselText getDynamischerWechselText()
  {
    return m_dynamischerWechselText;
  }

  /**
   * Methode setzt die Variable m_dynamischerWechselText
   * @param dynamischerWechselText Wert auf den die Variable m_dynamischerWechselText gesetzt werden soll
   */
  public void setDynamischerWechselText( DynamischerWechselText dynamischerWechselText )
  {
    m_dynamischerWechselText = dynamischerWechselText;
  }
  
  /**
   * Methode zum Auswerten der Attributgruppe des DaV die den WVZ-Inhalt darstellt.
   * @param data Datensatz vom DaV
   */
  public void auswerteAttributgruppe (Data data)
  {
    m_anzeigenInhalt = data.getReferenceValue( "AnzeigeInhalt" ).getSystemObject();
    
    setBlinken( data.getItem( "Blinken" ).asTextValue().getText().equalsIgnoreCase( "Ja" ) );
    
    if (data.getItem( "Blinktakt" ).asScaledValue().isNumber())
    	m_blinkTakt = data.getItem( "Blinktakt" ).asScaledValue().floatValue();
    else
    	m_blinkTakt = -1;
    
    synchronized (m_grafikDarstellungen)
    {
      m_grafikDarstellungen.clear();
      
      ReferenceArray grafik = data.getReferenceArray( "GrafikDarstellungen" );
      int anzahl = grafik.getLength();
      for (int x = 0; x < anzahl; ++x)
      {
        SystemObject o = grafik.getSystemObject( x );
        
        m_grafikDarstellungen.add( o );
      }
    }
    
    m_wechselText = data.getReferenceValue( "Wechseltext" ).getSystemObject();
    
    Data dynWechselText = data.getItem( "DynamischerWechseltext" );
    m_dynamischerWechselText.auswerteAttributGruppe( dynWechselText );
    
    m_wvzInhalt = data;
  }

  /**
   * Methode zum Ausgeben des WVZInhalts als String
   */
  public String toString ()
  {
    String s = "";
    
    if (getAnzeigenInhalt() != null)
      s += "Anzeigeninhalt: " + getAnzeigenInhalt().getName() + "\n";
    else
    {
      s += "Anzeigeninhalt: " + "null\n";
    
      s += "Blinken:        " + isBlinken() + "\n";
      s += "Blinktakt:      " + getBlinkTakt() + "\n";
      s += "Grafikdarstellung:" + "\n";
      for (SystemObject o : getGrafikDarstellungen())
        s += "-" + o.getPid() + "\n";
      s += "Wechseltext:    " + getWechselText() + "\n";
      s += m_dynamischerWechselText.toString();
    }
    
    return s;
  }
  
  /**
   * Methode prft ob zwei Objekte vom Typ WVZInhalt inhaltlich gleich sind.<br>
   * Dabei wird wie folgt vorgegangen:<br>
   * 1. Prfen ob der Anzeigeinhalt versorgt ist, wenn ja werden nur die zum Anzeigeinhalt
   * gehrenden Attribute (Inhalt + Blinken) verglichen.<br>
   * 2. Prfen ob ein Grafikdarstellung versorgt ist, wenn ja wird nur die Grafikdarstellung 
   * verglichen<br>
   * 3. Prfen ob ein Wechseltext versorgt ist, wenn ja wird nur der Wechseltext verglichen<br>
   * 4. Prfen ob ein dyn. Wechseltext versorgt ist, wenn ja wird nur der dyn. Wechseltext verglichen<br>
   * 5. Wenn kein sinnvollers Schaltbild bei dem aktuellen und dem zu vergleichenden WVZInhalt vorliegt,
   * wird true zurckgeliefert.<br>
   * @param vgl Objekt mit dem verglichen werden soll
   * @return wenn Inhalt entsprechend obiger Kriterien identisch ist dann true, sonst false
   */
  public boolean isInhaltlichGleich (WVZInhalt vgl)
  {
    // 1. Prfen ob Anzeigeninhalt als SystemObjekt vorgegeben wurde
    
    if (getAnzeigenInhalt() != null || vgl.getAnzeigenInhalt() != null)
    {
      if (getAnzeigenInhalt() != vgl.getAnzeigenInhalt())
        return false;
      
      if (isBlinken() != vgl.isBlinken())
        return false;
      
      if (isBlinken())
      {
	      if (getBlinkTakt() != vgl.getBlinkTakt())
	        return false;
      }
      
      return true;
    }
    
    // 2. Prfen der Grafikdarstellung
    
    if (getGrafikDarstellungen().size() > 0 || vgl.getGrafikDarstellungen().size() > 0)
    {
      Vector<SystemObject> gd1 = getGrafikDarstellungen();
      Vector<SystemObject> gd2 = vgl.getGrafikDarstellungen();

      if (gd1.size() != gd2.size())
        return false;
      
      for (int i = 0; i<gd1.size(); ++i)
      {
        if (gd1.get( i ) != gd2.get( i ))
          return false;
      }
      
      return true;
    }
    
    // 3. Prfen des Wechseltextes
    
    if (getWechselText() != null || vgl.getWechselText() != null)
    {
      if (getWechselText() != vgl.getWechselText())
        return false;
      
      return true;
    }
    
    // 4. Dynamischer Wechseltext
    
    if ((getDynamischerWechselText().getTextDefinition().size() > 0) ||
        (vgl.getDynamischerWechselText().getTextDefinition().size() > 0))
    {
      DynamischerWechselText wt1 = getDynamischerWechselText();
      DynamischerWechselText wt2 = vgl.getDynamischerWechselText();
      
      if (!wt1.isInhaltlichGleich(wt2))
        return false;
      
      return true;
    }
      
    return true;
  }

	/**
	 * Gibt den Datensatz Wvzinhalt zurck.
	 * @return Datensatz Wvzinhalt.
	 */
	public Data getWvzInhalt()
	{
		return m_wvzInhalt;
	}

	/**
	 * Setzt den Datensatz Wvzinhalt.
	 * @param wvzInhalt zu setzender Wert fr den WVZ-Inhalt.
	 */
	public void setWvzInhalt(Data wvzInhalt)
	{
		m_wvzInhalt = wvzInhalt;
	}

	/**
	 * Gibt den Wert der Variable m_prioritaet zurck.
	 *
	 * @return Wert der Variable m_prioritaet.
	 */
	public int getPrioritaet()
	{
		return m_prioritaet;
	}

	/**
	 * Setzt den Wert der Variable m_prioritaet.
	 *
	 * @param prioritaet zu setzender Wert der Variable m_prioritaet.
	 */
	public void setPrioritaet(int prioritaet)
	{
		m_prioritaet = prioritaet;
	}
}
