/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

import java.util.Vector;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeStauBeleg!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.3 $ / $Date: 2015/03/03 14:26:00 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterStauBeleg
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeStauBeleg";
	/**
	 * Grenzwert Gte.
	 */
	private float m_guete;	
	/**
	 * Grenzwerte pro Fahrstreifen.
	 */
	private Vector<ParameterStauBelegFahrstreifen> m_fahrstreifen = new Vector<ParameterStauBelegFahrstreifen>();
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterStauBeleg()
	{
	}
	/**
	 * Konstruktor mit bernahme des bergebenen Datensatzes in die interne Struktur.
	 *  
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterStauBeleg(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
				m_fahrstreifen.clear();
				
				m_guete = data.getScaledValue("Gte").floatValue();

				for (int i = 0; i < data.getArray("GrenzwerteFahrstreifen").getLength(); i++)
				{
					Data element = data.getArray("GrenzwerteFahrstreifen").getItem(i);
					if (element != null)
					{
						ParameterStauBelegFahrstreifen fsWerte = new ParameterStauBelegFahrstreifen();
						fsWerte.setBStauEin(element.getUnscaledValue("bStauEin").intValue());
						fsWerte.setBStauAus(element.getUnscaledValue("bStauAus").intValue());
						fsWerte.setVStauEin(element.getUnscaledValue("VStauEin").intValue());
						
						addFahrstreifen(fsWerte);
					}
				}
			}
			else
			{
				m_guete = 0.0F;
				m_fahrstreifen.clear();
			}
		}		
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeHarmoGeschwDiff</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{	
			dataNeu.getScaledValue("Gte").set(m_guete);			
			dataNeu.getArray("GrenzwerteFahrstreifen").setLength(0);
			
			for (int i = 0; i < m_fahrstreifen.size(); i++)
			{
				ParameterStauBelegFahrstreifen fsWerte = m_fahrstreifen.get(i);
				if (fsWerte != null)
				{
					dataNeu.getArray("GrenzwerteFahrstreifen").setLength(i+1);
					Data element = dataNeu.getArray("GrenzwerteFahrstreifen").getItem(i);

					element.getUnscaledValue("bStauEin").set(fsWerte.getBStauEin());
					element.getUnscaledValue("bStauAus").set(fsWerte.getBStauAus());
					element.getUnscaledValue("VStauEin").set(fsWerte.getVStauEin());					
				}
			}
			
			return dataNeu;
		}
		
		return null;
	}
	
	/**
	 * Gibt die Grenzwerte pro Fahrstreifen zurck.
	 * @return Grenzwerte pro Fahrstreifen.
	 */
	public Vector<ParameterStauBelegFahrstreifen> getFahrstreifen()
	{
		return m_fahrstreifen;
	}

	/**
	 * Gibt die Grenzwerte Fahrstreifen fr den bergebenen Index zurck.
	 * @return Grenzwerte Fahrstreifen.
	 */
	public ParameterStauBelegFahrstreifen getParameterFahrstreifen(int index)
	{
		if (m_fahrstreifen != null)
		{
			if (m_fahrstreifen.size() > 0)
			{
				if (index < m_fahrstreifen.size())
				{
					return m_fahrstreifen.get(index);
				}
				else
				{
					return m_fahrstreifen.lastElement();
				}
			}
		}
		return null;
	}
/**
	 * Setzt die Grenzwerte pro Fahrstreifen.
	 * @param fahrstreifen zu setzende Grenzwerte pro Fahrstreifen.
	 */
	public void setFahrstreifen(Vector<ParameterStauBelegFahrstreifen> fahrstreifen)
	{
		m_fahrstreifen = fahrstreifen;
	}

	/**
	 * Fgt zu der Liste den bergebenen Parameter hinzu. 
	 * @param fahrstreifen Parameter fr den fahrstreifen.
	 */
	public void addFahrstreifen(ParameterStauBelegFahrstreifen fahrstreifen)
	{
		if (m_fahrstreifen == null)
		{
			m_fahrstreifen = new Vector<ParameterStauBelegFahrstreifen>();			
		}
		
		m_fahrstreifen.add(fahrstreifen);
	}
	/**
	 * Gibt den Grenzwert Gte zurck.
	 * 
	 * @return Grenzwert Gte.
	 */
	public float getGuete()
	{
		return m_guete;
	}
	/**
	 * Setzt den Grenzwert Gte.
	 * 
	 * @param guete zu setzender Grenzwert Gte.
	 */
	public void setGuete(float guete)
	{
		m_guete = guete;
	}

	/**
	 * Innere Klasse zum Speichern der Grenzwerte pro Fahrstreifen.
	 *
	 * @version $Revision: 1.3 $ / $Date: 2015/03/03 14:26:00 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class ParameterStauBelegFahrstreifen
	{
		/**
		 * Einschaltkriterium Belegung in Prozent.
		 */
		private int m_bStauEin;
		/**
		 * Ausschaltkriterium Belegung in Prozent.
		 */
		private int m_bStauAus;
		/**
		 * Einschaltkriterium Geschwindigkeit Stau.
		 */
		private int m_vStauEin;	

		/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
		public ParameterStauBelegFahrstreifen()
		{
			
		}
		
		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" bStauEin " + m_bStauEin +
										" bStauAus " + m_bStauAus +
					          " vStauEin " + m_vStauEin +
					          " Gte " + m_guete);
			
			return string.toString();
	  }
		/**
		 * Gibt das Einschaltkriterium Belegung in Prozent zurck.
		 * 
		 * @return Einschaltkriterium Belegung in Prozent.
		 */
		public int getBStauEin()
		{
			return m_bStauEin;
		}
		/**
		 * Setzt das Einschaltkriterium Belegung in Prozent.
		 * 
		 * @param stauEin zu setzendes Einschaltkriterium Belegung in Prozent.
		 */
		public void setBStauEin(int stauEin)
		{
			m_bStauEin = stauEin;
		}
		/**
		 * Gibt das Ausschaltkriterium Belegung in Prozent zurck.
		 * 
		 * @return Ausschaltkriterium Belegung in Prozent.
		 */
		public int getBStauAus()
		{
			return m_bStauAus;
		}
		/**
		 * Setzt das Ausschaltkriterium Belegung in Prozent.
		 * 
		 * @param stauAus zu setzendes Ausschaltkriterium Belegung in Prozent.
		 */
		public void setBStauAus(int stauAus)
		{
			m_bStauAus = stauAus;
		}
		
		/**
		 * Gibt das Einschaltkriterium Geschwindigkeit Stau zurck.
		 * 
		 * @return Einschaltkriterium Geschwindigkeit Stau.
		 */
		public int getVStauEin()
		{
			return m_vStauEin;
		}
		/**
		 * Setzt das Einschaltkriterium Geschwindigkeit Stau.
		 * 
		 * @param stauEin zu setzendes Einschaltkriterium Geschwindigkeit Stau.
		 */
		public void setVStauEin(int stauEin)
		{
			m_vStauEin = stauEin;
		}

	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "ParameterStauBeleg [m_pidAtg=" + m_pidAtg + ", m_guete=" + m_guete + ", m_fahrstreifen=" + m_fahrstreifen + "]";
	}

}