/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

import java.util.ArrayList;
import java.util.List;
import java.util.Vector;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeStauStrfall!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.3 $ / $Date: 2013/02/14 07:32:49 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterStauStoerfall
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeStauStrfall";
	/**
	 * Definition der Straenabschnitte.
	 */
	private Vector<ParameterStauStoerfallStrassenAbschnitt> m_straenAbschnitt = new Vector<ParameterStauStoerfallStrassenAbschnitt>();
	/**
	 * Grenzwert Gte.
	 */
	private float m_guete;
	/**
	 * Parameterversorgung fr 2 Fahrstreifen.
	 */
	private ParameterStauStoerfallFahrstreifen m_fahrstreifen2;

	/**
	 * Parameterversorgung fr 3 Fahrstreifen.
	 */
	private ParameterStauStoerfallFahrstreifen m_fahrstreifen3;


	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterStauStoerfall()
	{
	}
	/**
	 * Konstruktor mit bernahme des bergebenen Datensatzes in die interne Struktur.
	 *  
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterStauStoerfall(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
				m_guete = data.getScaledValue("Gte").floatValue();
				
				for (int i = 0; i < data.getArray("StraenAbschnitt").getLength(); i++)
				{
					ParameterStauStoerfallStrassenAbschnitt abschnitt = new ParameterStauStoerfallStrassenAbschnitt();
					abschnitt.setVonMessQuerschnitt(data.getArray("StraenAbschnitt").getItem(i).getReferenceValue("vonMessQuerschnitt").getSystemObject());
					abschnitt.setBisMessQuerschnitt(data.getArray("StraenAbschnitt").getItem(i).getReferenceValue("bisMessQuerschnitt").getSystemObject());

					m_straenAbschnitt.add(abschnitt);
				}
				
				if (m_fahrstreifen2 == null)
					m_fahrstreifen2 = new ParameterStauStoerfallFahrstreifen();
							
				m_fahrstreifen2.setVFrei(data.getItem("2Fahrstreifen").getUnscaledValue("Vfrei").intValue());
				m_fahrstreifen2.setDMax(data.getItem("2Fahrstreifen").getUnscaledValue("Dmax").intValue());
				m_fahrstreifen2.setVkGrenzEin(data.getItem("2Fahrstreifen").getScaledValue("VkGrenzEin").floatValue());
				m_fahrstreifen2.setVkGrenzAus(data.getItem("2Fahrstreifen").getScaledValue("VkGrenzAus").floatValue());
				m_fahrstreifen2.setQKfzDiffEin(data.getItem("2Fahrstreifen").getUnscaledValue("QKfzDiffEin").intValue());
				m_fahrstreifen2.setQKfzDiffAus(data.getItem("2Fahrstreifen").getUnscaledValue("QKfzDiffAus").intValue());

				if (m_fahrstreifen3 == null)
					m_fahrstreifen3 = new ParameterStauStoerfallFahrstreifen();
							
				m_fahrstreifen3.setVFrei(data.getItem("3Fahrstreifen").getUnscaledValue("Vfrei").intValue());
				m_fahrstreifen3.setDMax(data.getItem("3Fahrstreifen").getUnscaledValue("Dmax").intValue());
				m_fahrstreifen3.setVkGrenzEin(data.getItem("3Fahrstreifen").getScaledValue("VkGrenzEin").floatValue());
				m_fahrstreifen3.setVkGrenzAus(data.getItem("3Fahrstreifen").getScaledValue("VkGrenzAus").floatValue());
				m_fahrstreifen3.setQKfzDiffEin(data.getItem("3Fahrstreifen").getUnscaledValue("QKfzDiffEin").intValue());
				m_fahrstreifen3.setQKfzDiffAus(data.getItem("3Fahrstreifen").getUnscaledValue("QKfzDiffAus").intValue());				
			}
			else
			{
				m_guete = 0.0F;
				m_straenAbschnitt.clear();
				m_fahrstreifen2 = new ParameterStauStoerfallFahrstreifen();
				m_fahrstreifen3 = new ParameterStauStoerfallFahrstreifen();
			}
		}		
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeHarmoGeschwDiff</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{	
			dataNeu.getScaledValue("Gte").set(m_guete);
			dataNeu.getArray("StraenAbschnitt").setLength(0);
			
			for (int i = 0; i < m_straenAbschnitt.size(); i++)
			{
				dataNeu.getArray("StraenAbschnitt").setLength(i+1);
				Data element = dataNeu.getArray("StraenAbschnitt").getItem(i);
								
				element.getArray("StraenAbschnitt").getItem(i).getReferenceValue("vonMessQuerschnitt").setSystemObject(m_straenAbschnitt.get(i).getVonMessQuerschnitt());
				element.getArray("StraenAbschnitt").getItem(i).getReferenceValue("bisMessQuerschnitt").setSystemObject(m_straenAbschnitt.get(i).getBisMessQuerschnitt());
			}
			
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("Vfrei").set(m_fahrstreifen2.getVFrei());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("Dmax").set(m_fahrstreifen2.getDMax());
			dataNeu.getItem("2Fahrstreifen").getScaledValue("VkGrentEin").set(m_fahrstreifen2.getVkGrenzEin());
			dataNeu.getItem("2Fahrstreifen").getScaledValue("VkGrentAus").set(m_fahrstreifen2.getVkGrenzAus());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QKfzDiffEin").set(m_fahrstreifen2.getQKfzDiffEin());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QKfzDiffAus").set(m_fahrstreifen2.getQKfzDiffAus());

			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("Vfrei").set(m_fahrstreifen3.getVFrei());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("Dmax").set(m_fahrstreifen3.getDMax());
			dataNeu.getItem("3Fahrstreifen").getScaledValue("VkGrentEin").set(m_fahrstreifen3.getVkGrenzEin());
			dataNeu.getItem("3Fahrstreifen").getScaledValue("VkGrentAus").set(m_fahrstreifen3.getVkGrenzAus());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QKfzDiffEin").set(m_fahrstreifen3.getQKfzDiffEin());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QKfzDiffAus").set(m_fahrstreifen3.getQKfzDiffAus());
			
			return dataNeu;
		}
		
		return null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append("Gte " + m_guete +
									"\n 2 Fahrstreifen " + m_fahrstreifen2 +
				          "\n 3 Fahrstreifen " + m_fahrstreifen3 +
				          "\n Abschnitte     " + m_straenAbschnitt);
		
		return string.toString();
  }

	/**
	 * Gibt fr die bergebene Anzahl Fahrstreifen den entsprechenden Datensatz zurck.
	 * 
	 * @param anzFs Anzahl der Fahrstreifen.
	 * @return Parameterversorgung der bergebenen Anzahl von Fahrstreifen.
	 */
	public ParameterStauStoerfallFahrstreifen getParameterFahrstreifen(int anzFs)
	{
		switch (anzFs)
		{
			case 2:
			{				
				return m_fahrstreifen2;
			}
			case 3:
			case 4:
			case 5:
			case 6:
			case 7:
			{				
				return m_fahrstreifen3;
			}
		}
		return null;
	}
	
	/**
	 * Prft, ob der bergebene Messquerschnitt in einem Straenabschnitt als einfahrend versorgt ist.
	 * @param pid PID Messquerschnitt.
	 * @return true wenn Messquerschnitt als einfahrend versorgt ist, ansonsten false.
	 */
	public boolean isMessQuerschnittEinfahrend(String pid)
	{
		if (m_straenAbschnitt != null)
		{
			for (int i = 0; i < m_straenAbschnitt.size(); i++)
			{
				if (m_straenAbschnitt.get(i).getVonMessQuerschnitt().getPid().equals(pid))
				{
					return true;
				}
			}
		}
		return false;
	}

	/**
	 * Prft, ob der bergebene Messquerschnitt in einem Straenabschnitt als einfahrend versorgt ist
	 * und gibt den dazu gehrenden ausfahrenden Messquerschnitt zurck.
	 * 
	 * @param pid PID Messquerschnitt.
	 * @return Objekt Messquerschnitt.
	 */
	public SystemObject getMessQuerschnittAusfahrend(String pid)
	{
		if (m_straenAbschnitt != null)
		{
			for (int i = 0; i < m_straenAbschnitt.size(); i++)
			{
				if (m_straenAbschnitt.get(i).getVonMessQuerschnitt().getPid().equals(pid))
				{
					return m_straenAbschnitt.get(i).getBisMessQuerschnitt();
				}
			}
		}
		return null;
	}

	/**
	 * Erstellt eine Liste aller ausfahrenden Messquerschnitte und gibt sie zurck.
	 * 
	 * @return Liste Objekt Messquerschnitt.
	 */
	public List<SystemObject> getListeMessQuerschnittAusfahrend()
	{
		if (m_straenAbschnitt != null)
		{
			List<SystemObject> _liste = new ArrayList<SystemObject>();
			
			for (int i = 0; i < m_straenAbschnitt.size(); i++)
			{
				_liste.add(m_straenAbschnitt.get(i).getBisMessQuerschnitt());
			}
		
			return _liste;
		}
		
		return null;
	}

	/**
	 * bernimmt die bergebenen Grenzwerte in die interne Struktur der parameter fr Fahrstreifen 2.
	 * 
	 * @param vFrei freie mittlere Geschwindigkeit.
	 * @param dMax Fahrzeugdichte bei maximaler Verkehrsstrke.
	 * @param vkGrenzEin Einschaltgrenzwert vkDiff.
	 * @param vkGrenzAus Ausschaltgrenzwert vkDiff.
	 * @param qKfzDiffEin Einschaltkriterium QKfzDiff.
	 * @param qKfzDiffAus Ausschaltkriterium QKfzDiff. 
	 */
	public void setWerteFahrstreifen2(int vFrei, int dMax, float vkGrenzEin, float vkGrenzAus, int qKfzDiffEin, int qKfzDiffAus)
	{
		if (m_fahrstreifen2 == null)
			m_fahrstreifen2 = new ParameterStauStoerfallFahrstreifen();
		
		m_fahrstreifen2.setVFrei(vFrei);
		m_fahrstreifen2.setDMax(dMax);
		m_fahrstreifen2.setVkGrenzEin(vkGrenzEin);
		m_fahrstreifen2.setVkGrenzAus(vkGrenzAus);
		m_fahrstreifen2.setQKfzDiffEin(qKfzDiffEin);
		m_fahrstreifen2.setVkGrenzAus(qKfzDiffAus);
	}

	/**
	 * bernimmt die bergebenen Grenzwerte in die interne Struktur der parameter fr Fahrstreifen 3.
	 * 
	 * @param vFrei freie mittlere Geschwindigkeit.
	 * @param dMax Fahrzeugdichte bei maximaler Verkehrsstrke.
	 * @param vkGrenzEin Einschaltgrenzwert vkDiff.
	 * @param vkGrenzAus Ausschaltgrenzwert vkDiff.
	 * @param qKfzDiffEin Einschaltkriterium QKfzDiff.
	 * @param qKfzDiffAus Ausschaltkriterium QKfzDiff. 
	 */
	public void setWerteFahrstreifen3(int vFrei, int dMax, float vkGrenzEin, float vkGrenzAus, int qKfzDiffEin, int qKfzDiffAus)
	{
		if (m_fahrstreifen3 == null)
			m_fahrstreifen3 = new ParameterStauStoerfallFahrstreifen();
		
		m_fahrstreifen3.setVFrei(vFrei);
		m_fahrstreifen3.setDMax(dMax);
		m_fahrstreifen3.setVkGrenzEin(vkGrenzEin);
		m_fahrstreifen3.setVkGrenzAus(vkGrenzAus);
		m_fahrstreifen3.setQKfzDiffEin(qKfzDiffEin);
		m_fahrstreifen3.setVkGrenzAus(qKfzDiffAus);
	}

	/**
	 * Gibt den Grenzwert Gte zurck.
	 * 
	 * @return Grenzwert Gte.
	 */
	public float getGuete()
	{
		return m_guete;
	}
	/**
	 * Setzt den Grenzwert Gte.
	 * @param guete zu setzender Grenzwert Gte.
	 */
	public void setGuete(float guete)
	{
		m_guete = guete;
	}

	/**
	 * Gibt die Parameterversorgung fr 2 Fahrstreifen zurck.
	 * 
	 * @return Parameterversorgung fr 2 Fahrstreifen.
	 */
	public ParameterStauStoerfallFahrstreifen getFahrstreifen2()
	{
		return m_fahrstreifen2;
	}

	/**
	 * Setzt die Parameterversorgung fr 2 Fahrstreifen.
	 * 
	 * @param fahrstreifen2 zu setzende Parameterversorgung fr 2 Fahrstreifen.
	 */
	public void setFahrstreifen2(ParameterStauStoerfallFahrstreifen fahrstreifen2)
	{
		m_fahrstreifen2 = fahrstreifen2;
	}

	/**
	 * Gibt die Parameterversorgung fr 3 Fahrstreifen zurck.
	 * 
	 * @return Parameterversorgung fr 3 Fahrstreifen.
	 */
	public ParameterStauStoerfallFahrstreifen getFahrstreifen3()
	{
		return m_fahrstreifen3;
	}

	/**
	 * Setzt die Parameterversorgung fr 3 Fahrstreifen.
	 * 
	 * @param fahrstreifen3 zu setzende Parameterversorgung fr 3 Fahrstreifen.
	 */
	public void setFahrstreifen3(ParameterStauStoerfallFahrstreifen fahrstreifen3)
	{
		m_fahrstreifen3 = fahrstreifen3;
	}
	/**
	 * Gibt die Straenabschnitte zurck.
	 * @return Straenabschnitte.
	 */
	public Vector<ParameterStauStoerfallStrassenAbschnitt> getStraenAbschnitt()
	{
		return m_straenAbschnitt;
	}

	/**
	 * Setzt die Straenabschnitte.
	 * @param straenAbschnitt zu setzende Straenabschnitte.
	 */
	public void setStraenAbschnitt(Vector<ParameterStauStoerfallStrassenAbschnitt> straenAbschnitt)
	{
		m_straenAbschnitt = straenAbschnitt;
	}

	
  /**
	 * Innere Klasse zum Speichern der Parameter pro Fahrstreifen.<p>
	 * ber Getter und Setter kann auf die Daten zugegriffen werden.
	 * 
   * @version $Revision: 1.3 $ / $Date: 2013/02/14 07:32:49 $ / ($Author: Asal $)
	 * @author  Swarco Traffic Systems GmbH
	 * @author  Matthias Obert
	 */
  public class ParameterStauStoerfallFahrstreifen
  {
  	/**
  	 * mittlere freie Geschwindigkeit in km/h.
  	 */
  	private int m_vFrei; 	
  	/**
  	 * Fahrzeugdichte bei maximaler Verkehrsstrke in Fz/km.
  	 */
  	private int m_dMax;
  	/**
  	 * Einschaltgrenzwert vkDiff.
  	 */
  	private float m_vkGrenzEin;
  	/**
  	 * Ausschaltgrenzwert vkDiff. 
  	 */
  	private float m_vkGrenzAus;
  	/**
  	 * Einschaltkriterium QKfzDiff Fz/h. 
  	 */
  	private int m_qKfzDiffEin;
  	/**
  	 * Ausschaltkriterium QKfzDiff Fz/h. 
  	 */
  	private int m_qKfzDiffAus;

  	
  	/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
  	public ParameterStauStoerfallFahrstreifen()
		{
		}

  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" vFrei " + m_vFrei +
					          " dMax " + m_dMax +
					          " vkGrenzEin " + m_vkGrenzEin +
					          " vkGrenzAus " + m_vkGrenzAus +
					          " qKfzDiffEin " + m_qKfzDiffEin +
					          " qKfzDiffAus " + m_qKfzDiffAus);
			
			return string.toString();
	  }

		/**
		 * Gibt die mittkere freie Geschwindigkeit in km/h zurck.
		 * 
		 * @return mittkere freie Geschwindigkeit in km/h.
		 */
		public int getVFrei()
		{
			return m_vFrei;
		}

		/**
		 * Setzt die mittkere freie Geschwindigkeit in km/h.
		 * 
		 * @param frei zu setzende mittkere freie Geschwindigkeit in km/h.
		 */
		public void setVFrei(int frei)
		{
			m_vFrei = frei;
		}

		/**
		 * Gibt die Fahrzeugdichte bei maximaler Verkehrsstrke in Fz/km zurck.
		 * 
		 * @return Fahrzeugdichte bei maximaler Verkehrsstrke in Fz/km.
		 */
		public int getDMax()
		{
			return m_dMax;
		}

		/**
		 * Setzt die Fahrzeugdichte bei maximaler Verkehrsstrke in Fz/km.
		 * 
		 * @param max zu setzende Fahrzeugdichte bei maximaler Verkehrsstrke in Fz/km.
		 */
		public void setDMax(int max)
		{
			m_dMax = max;
		}

		/**
		 * Gibt den Einschaltgrenzwert vkDiff zurck.
		 * 
		 * @return Einschaltgrenzwert vkDiff.
		 */
		public float getVkGrenzEin()
		{
			return m_vkGrenzEin;
		}

		/**
		 * Setzt den Einschaltgrenzwert vkDiff.
		 * 
		 * @param vkGrenzEin zu setzender Einschaltgrenzwert vkDiff.
		 */
		public void setVkGrenzEin(float vkGrenzEin)
		{
			m_vkGrenzEin = vkGrenzEin;
		}

		/**
		 * Gibt den Ausschaltgrenzwert vkDiff zurck.
		 * 
		 * @return Ausschaltgrenzwert vkDiff.
		 */
		public float getVkGrenzAus()
		{
			return m_vkGrenzAus;
		}

		/**
		 * Setzt den Ausschaltgrenzwert vkDiff.
		 * 
		 * @param vkGrenzAus zu setzender Ausschaltgrenzwert vkDiff.
		 */
		public void setVkGrenzAus(float vkGrenzAus)
		{
			m_vkGrenzAus = vkGrenzAus;
		}

		/**
		 * Gibt das Einschaltkriterium QKfzDiff Fz/h zurck.
		 * 
		 * @return Einschaltkriterium QKfzDiff Fz/h.
		 */
		public int getQKfzDiffEin()
		{
			return m_qKfzDiffEin;
		}

		/**
		 * Setzt das Einschaltkriterium QKfzDiff Fz/h.
		 * 
		 * @param kfzDiffEin zu setzendes Einschaltkriterium QKfzDiff Fz/h.
		 */
		public void setQKfzDiffEin(int kfzDiffEin)
		{
			m_qKfzDiffEin = kfzDiffEin;
		}

		/**
		 * Gibt das Ausschaltkriterium QKfzDiff Fz/h zurck.
		 * 
		 * @return Ausschaltkriterium QKfzDiff Fz/h.
		 */
		public int getQKfzDiffAus()
		{
			return m_qKfzDiffAus;
		}

		/**
		 * Setzt das Ausschaltkriterium QKfzDiff Fz/h.
		 * 
		 * @param kfzDiffAus zu setzendes Ausschaltkriterium QKfzDiff Fz/h.
		 */
		public void setQKfzDiffAus(int kfzDiffAus)
		{
			m_qKfzDiffAus = kfzDiffAus;
		}
  }
  
  /**
   * Innere Klasse zum Speichern der Daten fr einen Straenabschnitt.
   *
   * @version $Revision: 1.3 $ / $Date: 2013/02/14 07:32:49 $ / ($Author: Asal $)
   *
   * @author Swarco Traffic Systems GmbH
   * @author Rolf Asal
   *
   */
  public class ParameterStauStoerfallStrassenAbschnitt
  {
  	/**
  	 * Einfahrquerschnitt dieses Straenabschnittes.
  	 */
  	private SystemObject m_vonMessQuerschnitt;
  	/**
  	 * Ausfahrquerschnitt dieses Straenabschnittes.
  	 */
  	private SystemObject m_bisMessQuerschnitt;
  	
  	/**
  	 * Default-Konstruktor ohne weitere Funktion.
  	 */
  	public ParameterStauStoerfallStrassenAbschnitt()
  	{  		
  	}
  	
  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" vonMQ " + m_vonMessQuerschnitt +
					          " bisMQ " + m_bisMessQuerschnitt);
			
			return string.toString();
	  }

		/**
		 * Gibt den Einfahrquerschnitt dieses Straenabschnittes zurck.
		 * @return Einfahrquerschnitt dieses Straenabschnittes.
		 */
		public SystemObject getVonMessQuerschnitt()
		{
			return m_vonMessQuerschnitt;
		}

		/**
		 * Setzt den Einfahrquerschnitt dieses Straenabschnittes.
		 * @param vonMessQuerschnitt zu setzender Einfahrquerschnitt dieses Straenabschnittes.
		 */
		public void setVonMessQuerschnitt(SystemObject vonMessQuerschnitt)
		{
			m_vonMessQuerschnitt = vonMessQuerschnitt;
		}

		/**
		 * Gibt den Ausfahrquerschnitt dieses Straenabschnittes zurck.
		 * @return Ausfahrquerschnitt dieses Straenabschnittes.
		 */
		public SystemObject getBisMessQuerschnitt()
		{
			return m_bisMessQuerschnitt;
		}

		/**
		 * Setzt den Ausfahrquerschnitt dieses Straenabschnittes.
		 * @param bisMessQuerschnitt zu setzender Ausfahrquerschnitt dieses Straenabschnittes.
		 */
		public void setBisMessQuerschnitt(SystemObject bisMessQuerschnitt)
		{
			m_bisMessQuerschnitt = bisMessQuerschnitt;
		}

  }
}