/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeStaukriterium!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.3 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterStaukriterium
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeStaukriterium";
	/**
	 * Parameterversorgung fr Staukriterium 1.
	 */
	private ParameterStaukriteriumKriterien m_staukriterium1;
	/**
	 * Parameterversorgung fr Staukriterium 2.
	 */
	private ParameterStaukriteriumKriterien m_staukriterium2;
	/**
	 * Parameterversorgung fr Staukriterium 3.
	 */
	private ParameterStaukriteriumKriterien m_staukriterium3;
	/**
	 * Parameterversorgung fr Staukriterium 4.
	 */
	private ParameterStaukriterium4 m_staukriterium4;
	/**
	 * Parameterversorgung fr Staukriterium 5.
	 */
	private ParameterStaukriteriumKriterien m_staukriterium5;
	/**
	 * Parameterversorgung fr Staukriterium 6.
	 */
	private ParameterStaukriteriumKriterien m_staukriterium6;
	/**
	 * Kennung, ob Modellerweiterung Staukriterium6 vorhanden ist.
	 */
	private boolean m_modellSk6Vorhanden = false;

	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterStaukriterium()
	{
	}
	/**
	 * Konstruktor mit bernahme des bergebenen Datensatzes in die interne Struktur.
	 *  
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterStaukriterium(ResultData rdata)
	{
		m_modellSk6Vorhanden = false;
		
		setdaten(rdata);
	}
	/**
	 * Konstruktor mit bernahme des bergebenen Datensatzes in die interne Struktur.
	 *  
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterStaukriterium(ResultData rdata, boolean modellSk6Vorhanden)
	{
		m_modellSk6Vorhanden = modellSk6Vorhanden;
		
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
				
				try
				{
					if (m_staukriterium1 == null)
						m_staukriterium1 = new ParameterStaukriteriumKriterien();
									
					m_staukriterium1.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium1").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium1.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium1").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
					m_staukriterium1.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium1").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium1.getStau().setZugehrigkeit(data.getItem("Staukriterium1").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());

					if (m_staukriterium2 == null)
						m_staukriterium2 = new ParameterStaukriteriumKriterien();
									
					m_staukriterium2.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium2").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium2.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium2").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
					m_staukriterium2.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium2").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium2.getStau().setZugehrigkeit(data.getItem("Staukriterium2").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());

					if (m_staukriterium3 == null)
						m_staukriterium3 = new ParameterStaukriteriumKriterien();
									
					m_staukriterium3.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium3").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium3.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium3").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
					m_staukriterium3.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium3").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium3.getStau().setZugehrigkeit(data.getItem("Staukriterium3").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());

					if (m_staukriterium4 == null)
						m_staukriterium4 = new ParameterStaukriterium4();
										
					m_staukriterium4.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium4").getItem("Staukriterium").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium4.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium4").getItem("Staukriterium").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
					m_staukriterium4.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium4").getItem("Staukriterium").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium4.getStau().setZugehrigkeit(data.getItem("Staukriterium4").getItem("Staukriterium").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());

					m_staukriterium4.getVerkehrsStufeNichtStau().setFreierVerkehr(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("freierVerkehr").floatValue());
					m_staukriterium4.getVerkehrsStufeNichtStau().setDichterVerkehr(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("dichterVerkehr").floatValue());
					m_staukriterium4.getVerkehrsStufeNichtStau().setZhfliessend(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("zhflieend").floatValue());
					m_staukriterium4.getVerkehrsStufeNichtStau().setStau(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("stau").floatValue());

					m_staukriterium4.getVerkehrsStufeStau().setFreierVerkehr(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("freierVerkehr").floatValue());
					m_staukriterium4.getVerkehrsStufeStau().setDichterVerkehr(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("dichterVerkehr").floatValue());
					m_staukriterium4.getVerkehrsStufeStau().setZhfliessend(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("zhflieend").floatValue());
					m_staukriterium4.getVerkehrsStufeStau().setStau(data.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("stau").floatValue());

					if (m_staukriterium5 == null)
						m_staukriterium5 = new ParameterStaukriteriumKriterien();
									
					m_staukriterium5.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium5").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium5.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium5").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
					m_staukriterium5.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium5").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
					m_staukriterium5.getStau().setZugehrigkeit(data.getItem("Staukriterium5").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());

					if (m_modellSk6Vorhanden)
					{
						if (m_staukriterium6 == null)
							m_staukriterium6 = new ParameterStaukriteriumKriterien();
										
						m_staukriterium6.getNichtStau().setVertrauenswrdigkeit(data.getItem("Staukriterium6").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
						m_staukriterium6.getNichtStau().setZugehrigkeit(data.getItem("Staukriterium6").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").floatValue());
						m_staukriterium6.getStau().setVertrauenswrdigkeit(data.getItem("Staukriterium6").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").floatValue());
						m_staukriterium6.getStau().setZugehrigkeit(data.getItem("Staukriterium6").getItem("Stau").getScaledValue("Zugehrigkeit").floatValue());
					}
				}
				catch (Exception e)
				{
					e.printStackTrace();
				}
			}
			else
			{
				m_staukriterium1 = new ParameterStaukriteriumKriterien();
				m_staukriterium2 = new ParameterStaukriteriumKriterien();
				m_staukriterium3 = new ParameterStaukriteriumKriterien();
				m_staukriterium4 = new ParameterStaukriterium4();
				m_staukriterium5 = new ParameterStaukriteriumKriterien();
				if (m_modellSk6Vorhanden)
					m_staukriterium6 = new ParameterStaukriteriumKriterien();
			}
		}		
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeHarmoGeschwDiff</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{	
			dataNeu.getItem("Staukriterium1").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium1.getNichtStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium1").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium1.getNichtStau().getZugehrigkeit());
			dataNeu.getItem("Staukriterium1").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium1.getStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium1").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium1.getStau().getZugehrigkeit());

			dataNeu.getItem("Staukriterium2").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium2.getNichtStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium2").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium2.getNichtStau().getZugehrigkeit());
			dataNeu.getItem("Staukriterium2").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium2.getStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium2").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium2.getStau().getZugehrigkeit());
		
			dataNeu.getItem("Staukriterium3").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium3.getNichtStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium3").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium3.getNichtStau().getZugehrigkeit());
			dataNeu.getItem("Staukriterium3").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium3.getStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium3").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium3.getStau().getZugehrigkeit());

			dataNeu.getItem("Staukriterium4").getItem("Staukriterium").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium4.getNichtStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium4").getItem("Staukriterium").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium4.getNichtStau().getZugehrigkeit());
			dataNeu.getItem("Staukriterium4").getItem("Staukriterium").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium4.getStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium4").getItem("Staukriterium").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium4.getStau().getZugehrigkeit());

			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("freierVerkehr").set(m_staukriterium4.getVerkehrsStufeNichtStau().getFreierVerkehr());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("dichterVerkehr").set(m_staukriterium4.getVerkehrsStufeNichtStau().getDichterVerkehr());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("zhflieend").set(m_staukriterium4.getVerkehrsStufeNichtStau().getZhfliessend());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Nicht-Stau").getScaledValue("stau").set(m_staukriterium4.getVerkehrsStufeNichtStau().getStau());

			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("freierVerkehr").set(m_staukriterium4.getVerkehrsStufeStau().getFreierVerkehr());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("dichterVerkehr").set(m_staukriterium4.getVerkehrsStufeStau().getDichterVerkehr());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("zhflieend").set(m_staukriterium4.getVerkehrsStufeStau().getZhfliessend());
			dataNeu.getItem("Staukriterium4").getItem("Verkehrsstufe").getItem("Stau").getScaledValue("stau").set(m_staukriterium4.getVerkehrsStufeStau().getStau());

			dataNeu.getItem("Staukriterium5").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium5.getNichtStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium5").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium5.getNichtStau().getZugehrigkeit());
			dataNeu.getItem("Staukriterium5").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium5.getStau().getVertrauenswrdigkeit());
			dataNeu.getItem("Staukriterium5").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium5.getStau().getZugehrigkeit());

			if (m_modellSk6Vorhanden)
			{
				dataNeu.getItem("Staukriterium6").getItem("Nicht-Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium6.getNichtStau().getVertrauenswrdigkeit());
				dataNeu.getItem("Staukriterium6").getItem("Nicht-Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium6.getNichtStau().getZugehrigkeit());
				dataNeu.getItem("Staukriterium6").getItem("Stau").getScaledValue("Vertrauenswrdigkeit").set(m_staukriterium6.getStau().getVertrauenswrdigkeit());
				dataNeu.getItem("Staukriterium6").getItem("Stau").getScaledValue("Zugehrigkeit").set(m_staukriterium6.getStau().getZugehrigkeit());
			}
			
			return dataNeu;
		}
		
		return null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		if (!m_modellSk6Vorhanden)
		{
			string.append("\n Staukriterium 1 " + m_staukriterium1 +
										"\n Staukriterium 2 " + m_staukriterium2 +
										"\n Staukriterium 3 " + m_staukriterium3 +
										"\n Staukriterium 4 " + m_staukriterium4 +
										"\n Staukriterium 5 " + m_staukriterium5);			
		}
		else
		{
			string.append("\n Staukriterium 1 " + m_staukriterium1 +
										"\n Staukriterium 2 " + m_staukriterium2 +
										"\n Staukriterium 3 " + m_staukriterium3 +
										"\n Staukriterium 4 " + m_staukriterium4 +
										"\n Staukriterium 5 " + m_staukriterium5 +			
										"\n Staukriterium 6 " + m_staukriterium6);			
		}
		
		return string.toString();
  }


	/**
	 * Gibt die Parameterversorgung fr Staukriterium 1 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 1.
	 */
	public ParameterStaukriteriumKriterien getStaukriterium1()
	{
		return m_staukriterium1;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 1.
	 * 
	 * @param staukriterium1 zu setzende Parameterversorgung fr Staukriterium 1.
	 */
	public void setStaukriterium1(ParameterStaukriteriumKriterien staukriterium1)
	{
		m_staukriterium1 = staukriterium1;
	}
	/**
	 * Gibt die Parameterversorgung fr Staukriterium 2 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 2.
	 */
	public ParameterStaukriteriumKriterien getStaukriterium2()
	{
		return m_staukriterium2;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 2.
	 * 
	 * @param staukriterium2 zu setzende Parameterversorgung fr Staukriterium 2.
	 */
	public void setStaukriterium2(ParameterStaukriteriumKriterien staukriterium2)
	{
		m_staukriterium2 = staukriterium2;
	}
	/**
	 * Gibt die Parameterversorgung fr Staukriterium 3 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 3.
	 */
	public ParameterStaukriteriumKriterien getStaukriterium3()
	{
		return m_staukriterium3;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 3.
	 * 
	 * @param staukriterium3 zu setzende Parameterversorgung fr Staukriterium 3.
	 */
	public void setStaukriterium3(ParameterStaukriteriumKriterien staukriterium3)
	{
		m_staukriterium3 = staukriterium3;
	}
	/**
	 * Gibt die Parameterversorgung fr Staukriterium 4 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 4.
	 */
	public ParameterStaukriterium4 getStaukriterium4()
	{
		return m_staukriterium4;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 4.
	 * 
	 * @param staukriterium4 zu setzende Parameterversorgung fr Staukriterium 4.
	 */
	public void setStaukriterium4(ParameterStaukriterium4 staukriterium4)
	{
		m_staukriterium4 = staukriterium4;
	}
	/**
	 * Gibt die Parameterversorgung fr Staukriterium 5 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 5.
	 */
	public ParameterStaukriteriumKriterien getStaukriterium5()
	{
		return m_staukriterium5;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 5.
	 * 
	 * @param staukriterium5 zu setzende Parameterversorgung fr Staukriterium 5.
	 */
	public void setStaukriterium5(ParameterStaukriteriumKriterien staukriterium5)
	{
		m_staukriterium5 = staukriterium5;
	}

	/**
	 * Gibt die Parameterversorgung fr Staukriterium 6 zurck.
	 * 
	 * @return Parameterversorgung fr Staukriterium 6.
	 */
	public ParameterStaukriteriumKriterien getStaukriterium6()
	{
		return m_staukriterium6;
	}
	/**
	 * Setzt die Parameterversorgung fr Staukriterium 6.
	 * 
	 * @param staukriterium5 zu setzende Parameterversorgung fr Staukriterium 6.
	 */
	public void setStaukriterium6(ParameterStaukriteriumKriterien staukriterium6)
	{
		m_staukriterium6 = staukriterium6;
	}
	
  /**
	 * Innere Klasse zum Speichern der Parameter pro Staukriterium.<p>
	 * ber Getter und Setter kann auf die Daten zugegriffen werden.
	 * 
   * @version $Revision: 1.3 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	 * @author  Swarco Traffic Systems GmbH
	 * @author  Matthias Obert
	 */
  public class ParameterStaukriteriumKriterien
  {
  	/**
  	 * Vorgabewerte fr Nicht-Stau.
  	 */
  	private ParameterStaukriteriumWerte m_nichtStau; 	
  	/**
  	 * Vorgabewerte fr Stau.
  	 */
  	private ParameterStaukriteriumWerte m_stau; 	

  	
  	/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
  	public ParameterStaukriteriumKriterien()
		{
		}

  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" nicht-Stau " + m_nichtStau +
					          " Stau " + m_stau);
			
			return string.toString();
	  }

		/**
		 * Gibt die Vorgabewerte fr Nicht-Stau zurck.
		 * 
		 * @return Vorgabewerte fr Nicht-Stau.
		 */
		public ParameterStaukriteriumWerte getNichtStau()
		{
			if (m_nichtStau == null)
			{
				m_nichtStau = new ParameterStaukriteriumWerte();
			}
			
			return m_nichtStau;
		}

		/**
		 * Setzt die Vorgabewerte fr Nicht-Stau.
		 * 
		 * @param nichtStau zu setzende Vorgabewerte fr Nicht-Stau.
		 */
		public void setNichtStau(ParameterStaukriteriumWerte nichtStau)
		{
			m_nichtStau = nichtStau;
		}

		/**
		 * Gibt die Vorgabewerte fr Stau zurck.
		 * 
		 * @return Vorgabewerte fr Stau.
		 */
		public ParameterStaukriteriumWerte getStau()
		{
			if (m_stau == null)
			{
				m_stau = new ParameterStaukriteriumWerte();
			}
			return m_stau;
		}

		/**
		 * Setzt die Vorgabewerte fr Stau.
		 * 
		 * @param stau zu setzende Vorgabewerte fr Stau.
		 */
		public void setStau(ParameterStaukriteriumWerte stau)
		{
			m_stau = stau;
		}	  
  }
  /**
   * Innere Klasse zum Speichern der Vorgabewerte Zugehrigkeit und Vertrauenswrdigkeit.
   *
   * @version $Revision: 1.3 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
   *
   * @author Swarco Traffic Systems GmbH
   * @author Rolf Asal
   *
   */
  public class ParameterStaukriteriumWerte
  {
  	/**
  	 * Vorgabe der Vertrauenswrdigkeit Wertebereich (0.00 - 1.00).
  	 */
  	private float m_vertrauenswrdigkeit; 	
  	/**
  	 * Vorgabe der Zugehrigkeit Wertebereich (0.00 - 1.00).
  	 */
  	private float m_zugehrigkeit;
  	
  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" Vertrauenswrdigkeit " + m_vertrauenswrdigkeit +
					          " Zugehrigkeit " + m_zugehrigkeit);
			
			return string.toString();
	  }

		/**
		 * Gibt die Vorgabe der Vertrauenswrdigkeit Wertebereich (0.00 - 1.00) zurck.
		 * 
		 * @return Vorgabe der Vertrauenswrdigkeit Wertebereich (0.00 - 1.00).
		 */
		public float getVertrauenswrdigkeit()
		{
			return m_vertrauenswrdigkeit;
		}

		/**
		 * Setzt die Vorgabe der Vertrauenswrdigkeit Wertebereich (0.00 - 1.00).
		 * 
		 * @param vertrauenswrdigkeit zu setzende Vorgabe der Vertrauenswrdigkeit Wertebereich (0.00 - 1.00).
		 */
		public void setVertrauenswrdigkeit(float vertrauenswrdigkeit)
		{
			m_vertrauenswrdigkeit = vertrauenswrdigkeit;
		}

		/**
		 * Gibt die Vorgabe der Zugehrigkeit Wertebereich (0.00 - 1.00) zurck.
		 * 
		 * @return Vorgabe der Zugehrigkeit Wertebereich (0.00 - 1.00).
		 */
		public float getZugehrigkeit()
		{
			return m_zugehrigkeit;
		}

		/**
		 * Setzt die Vorgabe der Zugehrigkeit Wertebereich (0.00 - 1.00).
		 * 
		 * @param zugehrigkeit zu setzende Vorgabe der Zugehrigkeit Wertebereich (0.00 - 1.00).
		 */
		public void setZugehrigkeit(float zugehrigkeit)
		{
			m_zugehrigkeit = zugehrigkeit;
		}
  }

  /**
	 * Innere Klasse zum Speichern der Parameter fr Staukriterium 4.<p>
	 * ber Getter und Setter kann auf die Daten zugegriffen werden.
	 * 
   * @version $Revision: 1.3 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	 * @author  Swarco Traffic Systems GmbH
	 * @author  Matthias Obert
	 */
  public class ParameterStaukriterium4
  {
  	/**
  	 * Vorgabewerte fr Nicht-Stau.
  	 */
  	private ParameterStaukriteriumWerte m_nichtStau; 	
  	/**
  	 * Vorgabewerte fr Stau.
  	 */
  	private ParameterStaukriteriumWerte m_stau; 	

  	/**
  	 * Vorgabewerte fr Nicht-Stau.
  	 */
  	private ParameterStaukriteriumVerkehrsstufeWerte m_verkehrsStufeNichtStau; 	
  	/**
  	 * Vorgabewerte fr Stau.
  	 */
  	private ParameterStaukriteriumVerkehrsstufeWerte m_verkehrsStufeStau; 	

  	
  	/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
  	public ParameterStaukriterium4()
		{
		}

  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" nicht-Stau " + m_verkehrsStufeNichtStau +
					          " Stau " + m_verkehrsStufeStau);
			
			return string.toString();
	  }

		/**
		 * Gibt die Vorgabewerte fr Nicht-Stau zurck.
		 * 
		 * @return Vorgabewerte fr Nicht-Stau.
		 */
		public ParameterStaukriteriumWerte getNichtStau()
		{
			if (m_nichtStau == null)
			{
				m_nichtStau = new ParameterStaukriteriumWerte();
			}
			
			return m_nichtStau;
		}

		/**
		 * Setzt die Vorgabewerte fr Nicht-Stau.
		 * 
		 * @param nichtStau zu setzende Vorgabewerte fr Nicht-Stau.
		 */
		public void setNichtStau(ParameterStaukriteriumWerte nichtStau)
		{
			m_nichtStau = nichtStau;
		}

		/**
		 * Gibt die Vorgabewerte fr Stau zurck.
		 * @return Vorgabewerte fr Stau.
		 */
		public ParameterStaukriteriumWerte getStau()
		{
			if (m_stau == null)
			{
				m_stau = new ParameterStaukriteriumWerte();
			}
			return m_stau;
		}

		/**
		 * Setzt die Vorgabewerte fr Stau.
		 * @param stau zu setzende Vorgabewerte fr Stau.
		 */
		public void setStau(ParameterStaukriteriumWerte stau)
		{
			m_stau = stau;
		}

		/**
		 * Gibt die Vorgabewerte fr Nicht-Stau zurck.
		 * 
		 * @return Vorgabewerte fr Nicht-Stau.
		 */
		public ParameterStaukriteriumVerkehrsstufeWerte getVerkehrsStufeNichtStau()
		{
			if (m_verkehrsStufeNichtStau == null)
			{
				m_verkehrsStufeNichtStau = new ParameterStaukriteriumVerkehrsstufeWerte();			
			}
			
			return m_verkehrsStufeNichtStau;
		}

		/**
		 * Setzt die Vorgabewerte fr Nicht-Stau.
		 * 
		 * @param nichtStau zu setzende Vorgabewerte fr Nicht-Stau.
		 */
		public void setVerkehrsStufeNichtStau(ParameterStaukriteriumVerkehrsstufeWerte nichtStau)
		{
			m_verkehrsStufeNichtStau = nichtStau;
		}

		/**
		 * Gibt die Vorgabewerte fr Stau zurck.
		 * 
		 * @return Vorgabewerte fr Stau.
		 */
		public ParameterStaukriteriumVerkehrsstufeWerte getVerkehrsStufeStau()
		{
			if (m_verkehrsStufeStau == null)
			{
				m_verkehrsStufeStau = new ParameterStaukriteriumVerkehrsstufeWerte();			
			}

			return m_verkehrsStufeStau;
		}

		/**
		 * Setzt die Vorgabewerte fr Stau.
		 * 
		 * @param stau zu setzende Vorgabewerte fr Stau.
		 */
		public void setVerkehrsStufeStau(ParameterStaukriteriumVerkehrsstufeWerte stau)
		{
			m_verkehrsStufeStau = stau;
		}

	  /**
	   * Innere Klasse zum Speichern der Vorgabewerte fr Staukriterium4.
	   *
	   * @version $Revision: 1.3 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	   *
	   * @author Swarco Traffic Systems GmbH
	   * @author Rolf Asal
	   *
	   */
	  public class ParameterStaukriteriumVerkehrsstufeWerte
	  {
	  	/**
	  	 * Verkehrszustandsklasse freier Verkehr.
	  	 */
	  	private float m_freierVerkehr; 	
	  	/**
	  	 * Verkehrszustandsklasse dichter Verkehr.
	  	 */
	  	private float m_dichterVerkehr; 	
	  	/**
	  	 * Verkehrszustandsklasse zhflieender Verkehr.
	  	 */
	  	private float m_zhfliessend; 	
	  	/**
	  	 * Verkehrszustandsklasse Stau.
	  	 */
	  	private float m_stau; 	
	  	
	  	/* (non-Javadoc)
			 * @see java.lang.Object#toString()
			 */
			@Override
			public String toString() 
			{
				StringBuffer string = new StringBuffer();
				
				string.append(" freierVerkehr " + m_freierVerkehr +
						          " dicherVerkehr " + m_dichterVerkehr +
						          " zhflieend " + m_zhfliessend +
						          " stau " + m_stau);
				
				return string.toString();
		  }

			/**
			 * Gibt die Verkehrszustandsklasse freier Verkehr zurck.
			 * @return Verkehrszustandsklasse freier Verkehr.
			 */
			public float getFreierVerkehr()
			{
				return m_freierVerkehr;
			}

			/**
			 * Setzt die Verkehrszustandsklasse freier Verkehr.
			 * @param freierVerkehr zu setzende Verkehrszustandsklasse freier Verkehr.
			 */
			public void setFreierVerkehr(float freierVerkehr)
			{
				m_freierVerkehr = freierVerkehr;
			}

			/**
			 * Gibt die Verkehrszustandsklasse dichter Verkehr zurck.
			 * @return Verkehrszustandsklasse dichter Verkehr.
			 */
			public float getDichterVerkehr()
			{
				return m_dichterVerkehr;
			}

			/**
			 * Setzt die Verkehrszustandsklasse dichter Verkehr.
			 * @param dichterVerkehr zu setzende Verkehrszustandsklasse dichter Verkehr.
			 */
			public void setDichterVerkehr(float dichterVerkehr)
			{
				m_dichterVerkehr = dichterVerkehr;
			}

			/**
			 * Gibt die Verkehrszustandsklasse zhflieender Verkehr zurck.
			 * @return Verkehrszustandsklasse zhflieender Verkehr.
			 */
			public float getZhfliessend()
			{
				return m_zhfliessend;
			}

			/**
			 * Setzt die Verkehrszustandsklasse zhflieender Verkehr.
			 * @param zhfliessend zu setzende Verkehrszustandsklasse zhflieender Verkehr.
			 */
			public void setZhfliessend(float zhfliessend)
			{
				m_zhfliessend = zhfliessend;
			}

			/**
			 * gibt die Verkehrszustandsklasse Stau zurck.
			 * @return Verkehrszustandsklasse Stau.
			 */
			public float getStau()
			{
				return m_stau;
			}

			/**
			 * Setzt die Verkehrszustandsklasse Stau.
			 * @param stau zu setzende Verkehrszustandsklasse Stau.
			 */
			public void setStau(float stau)
			{
				m_stau = stau;
			}
	  }
  }
}