/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

import static org.junit.Assert.fail;

import java.util.ArrayList;
import java.util.List;
import java.util.Vector;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.ClientDavParameters;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.DynamicObject;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ste.stealgsba.algorithmen.lib.DefinitionenGlobal;
import de.bsvrz.ste.stealgsba.algorithmen.lib.EinzelsituationVorstufeEmpfang;
import de.bsvrz.ste.stealgsba.algorithmen.lib.INeueDatenListener;
import de.bsvrz.ste.stealgsba.algorithmen.lib.SenderOhneStatusRueckmeldung;
import de.bsvrz.ste.stealgsba.algorithmen.lib.SimpleSenderMitWartenAufParametrierung;
import de.bsvrz.ste.stealgsba.algorithmen.lib.SituationAnalyseMq;
import de.bsvrz.ste.stealgsba.algorithmen.lib.SituationAnalyseMqEmpfang;
import de.bsvrz.ste.stealgsba.algorithmen.lib.StaukriteriumErgebnis;
import de.bsvrz.ste.stealgsba.algorithmen.lib.StaukriteriumErgebnisEmpfang;
import de.bsvrz.ste.stealgsba.algorithmen.lib.TestTools;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.AnzeigenDatensatz;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.EinzelMassnahmeAlternative;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.Massnahmenanforderung;
import de.bsvrz.sys.funclib.application.StandardApplicationRunner;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.losb.exceptions.SenderException;
import de.bsvrz.sys.funclib.vewdynobj.VerwaltungDynObj;

/**
 * Klasse fr die Durchfhrung der Prfflle 13.8 und 13.9 wie in der Prfspezifikation beschrieben.
 *
 * @version $Revision: 1.3 $ / $Date: 2013/09/13 04:43:19 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class StauTest implements INeueDatenListener
{
  /**
   * Datenverteilerverbindung.
   */
  private static ClientDavInterface m_connection = null;
  /**
   * Aktuelles Datenmodell.
   */
  private static DataModel m_dataModel;
  
  /**
   * Typ der Ursacheneinheit.
   */
  private static String m_typUe;
  /**
   * Pid der Ursacheneinheit.
   */
  private static String m_pidUe;
  /**
   * Name der Ursacheneinheit.
   */
  private static String m_nameUe;
  /**
   * Pid der Streckenbeeinflussungsanlage.
   */
  private static String m_anlage;
  /**
   * Synchronisierungsobjekt.
   */
  private static Object m_objekt;
  /**
   * Synchronisierungsobjekt.
   */
  private static Object m_objekt2;
  /**
   * Pid der Anzeige.
   */
  private static String m_pidAnzeige;
  /**
   * Pid des Messquerschnitt.
   */
  private static String m_pidMessQuerschnitt;	
  /**
   * Datensatz Einzelsituationvorstufe.
   */
  private static ResultData m_DatensatzEinzelsituationVorstufe = null;
	/**
	 * Analysedaten.
	 */
	private static SituationAnalyseMq m_analyseMq = null;	
  /**
   * Zugriff auf die Instanz des Algorithmus.
   */
  private static StauAlg m_alg;
  /**
   * Zugriff auf die Instanz der Verwaltung dynamischer Objekte.
   */
  private static VerwaltungDynObj m_vdo;  
	/**
	 * Liste mit Fahrstreifenobjekten.
	 */
	private static List<SystemObject> m_fahrstreifen = new ArrayList<SystemObject>();
	/**
	 * Liste mit Messquerschnitten.
	 */
	private static List<SystemObject> m_messquerschnitte = new ArrayList<SystemObject>();	
  /**
   * Flag Daten erhalten.
   */
  private static boolean m_datenErhalten = false;
	/**
	 * Flag Analysedaten erhalten.
	 */
	private static boolean m_analyseMqErhalten = false;
	/**
	 * Ergebnisse der Staukriterien.
	 */
	private static StaukriteriumErgebnis m_staukriterium = null;
	/**
	 * Flag Staukriterium erhalten.
	 */
	private static boolean m_staukriteriumErhalten = false;
	/**
	 * Definition der Pruefflle.
	 *
	 * @version $Revision: 1.3 $ / $Date: 2013/09/13 04:43:19 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public enum Prueffall
	{
		/**
		 * Prffall 1.
		 */
		PRF1,
		/**
		 * Prffall 2 Parametrierung.
		 */
		PRF2;
	}
	
  /**
   * Initialisiert die Testumgebung.
   * @throws Exception
   */
  @BeforeClass
  public static void setUpBeforeClass() throws Exception
  {
  	// Globale Daten setzen
    m_pidAnzeige = "bw.uz.B27.streckenBeeinflussungsAnlage.testAnzeigeQuerschnitt1.anzeige1";
    m_pidMessQuerschnitt = "mq.MQ.B27.4202.HFB.N"; 	
    m_anlage = DefinitionenGlobal.getAnlage();
    m_typUe = "typ.sswSbaUeStau";
    m_pidUe = "bw.uz.B27.UeStau.JUnitTest1";
    m_nameUe = "UrsachenEinheitStau.JUnitTest1";

    // Debug-Level setzen    
    Debug.setLoggerLevel("DEFAULT", Debug.OFF);
    Debug.setHandlerLevel("StdErr", Debug.OFF);
    
    // Datenverteilerverbindung aufbauen    
    ClientDavParameters parameters = new ClientDavParameters();
    parameters.setDavCommunicationAddress(DefinitionenGlobal.getDavCommunicationAddress());
    parameters.setDavCommunicationSubAddress(DefinitionenGlobal.getDavCommunicationSubAddress());
    parameters.setUserName(DefinitionenGlobal.getUserName());
    parameters.setUserPassword(DefinitionenGlobal.getUserPassword());

    m_connection = new ClientDavConnection(parameters);
    m_connection.connect();
    m_connection.login();
    m_dataModel = m_connection.getDataModel();
    
    // Synchronisierungsobjekte erstellen
    m_objekt = new Object();
    m_objekt2 = new Object();
    
    // Aufrufparameter definieren
    String[] argumente = 
    {
     	DefinitionenGlobal.getArgumentDav(),
     	DefinitionenGlobal.getArgumentBenutzer(),
     	DefinitionenGlobal.getArgumentDebugLevelStdErrText(),
     	DefinitionenGlobal.getArgumentAuthentifizierung(),
  		"-Anlage=" + DefinitionenGlobal.getAnlage(),
  		"-AspektVersand=asp.sswSbaStau",
  		DefinitionenGlobal.getMaxZyklusDauer(),
  		DefinitionenGlobal.getZyklusLaenge(),
  		DefinitionenGlobal.getDeltaPruefen(),
  		"-Spontan=true"
    };
    
    // Objekte erstellen
		m_messquerschnitte.add(m_dataModel.getObject(m_pidMessQuerschnitt));

		for (int i = 0; i < m_messquerschnitte.size(); i++)
		{
			m_fahrstreifen = bildeListeFahrstreifen(m_messquerschnitte);			
		}

		// Algorithmus instanziieren und starten
    m_alg = new StauAlg();
    
//    StandardApplicationRunner.run(new HarmoBelastungUnruhe120Alg(), argumente);
    StandardApplicationRunner.run(m_alg, argumente);
    
    // UE erzeugen und in Menge legen            
    m_vdo = new VerwaltungDynObj();
    m_vdo.setConnection(m_connection);
    
    try
		{
    	m_vdo.reduziereMenge(m_pidUe, "UrsachenEinheiten", m_anlage);
			m_vdo.loescheObjekt(m_pidUe);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}

    try
		{
			m_vdo.erzeugeObjekt(m_typUe, m_pidUe, m_nameUe, null);
			m_vdo.erweitereMenge(m_pidUe, "UrsachenEinheiten", m_anlage);
		}
		catch (Exception e1)
		{
			e1.printStackTrace();
			
      fail("Ursacheneinheit konnte nicht erstellt werden");
		}
  }

  @AfterClass
  public static void tearDownAfterClass() throws Exception
  {
  	m_vdo.reduziereMenge(m_pidUe, "UrsachenEinheiten", m_anlage);
  	m_vdo.loescheObjekt(m_pidUe);

  	m_connection.disconnect(false, "");    
  }


  @Before
  public void setUp() throws Exception
  {
  }

  @After
  public void tearDown() throws Exception
  {
  }

  /**
   * In diesem Testfall werden die in der Prfspezifikation definierten Testflle
   * fr den Prffall 13.8 durchgefhrt.
   */
  @Test
  public final void prueffall_13_8 ()
  {
  	Prueffall prueffall = Prueffall.PRF1;
  	
  	prueffall_13_8_Vorbereitung();
  	prueffall_13_8_Parametrierung(prueffall);
  	prueffall_13_8_Test_1();
  	prueffall_13_8_Test_2();
  	prueffall_13_8_Test_3();
  	prueffall_13_8_Test_4();
  	prueffall_13_8_Test_5();
  }

  /**
   * In diesem Testfall werden die in der Prfspezifikation definierten Testflle
   * fr den Prffall 13.9 durchgefhrt.
   */
  @Test
  public final void prueffall_13_9 ()
  {
  	Prueffall prueffall = Prueffall.PRF2;
  	
  	prueffall_13_8_Vorbereitung();
  	prueffall_13_8_Parametrierung(prueffall);
  	prueffall_13_8_Test_1();
  	prueffall_13_9_Test_2();
  	prueffall_13_8_Test_3();
  	prueffall_13_8_Test_4();
  	prueffall_13_8_Test_5();
  }

  /**
   * In diesem Testfall wird berprft, ob die fr den JUnitTest notwendige Ursacheneinheit
   * korrekt erstellt wurde und vom Steuerungsalgorithmus bearbeitet wird. berprft wird
   * hierzu der Empfang der Statusinformation "EinzelsituationVorstufe", die nach dem Berechnen
   * versendet wird.
   */
  private void prueffall_13_8_Vorbereitung ()
  {
  	DynamicObject ue = (DynamicObject)TestTools.getDynObjAusMenge(m_connection, m_anlage, "UrsachenEinheiten", m_pidUe);
  	
    EinzelsituationVorstufeEmpfang esve = new EinzelsituationVorstufeEmpfang(m_connection, ue);
    esve.addListener(this);
    
    StaukriteriumErgebnisEmpfang skee = new StaukriteriumErgebnisEmpfang(m_connection, ue);
    skee.addListener(this);
    
    m_alg.starteBerechnung();
    
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(65000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}
    		
		if (!m_datenErhalten)
			fail ("Vorbereitung EinzelsituationVorstufe nicht empfangen, Ursacheneinheit nicht korrekt erstellt");

    SituationAnalyseMqEmpfang samqe = new SituationAnalyseMqEmpfang(m_connection, ue);
    samqe.addListener(this);

  }
  
  /**
   * In diesem Tesfall werden folgende Attribitgruppen der Ursacheneinheit parametriert.<p>
   * - atg.sswSbaEinzelMassnahme<br>
   * - atg.sswSbaUrsachenEinheit<br>
   * - atg.sswSbaUeMqZuordnung<p>
   */
  private void prueffall_13_8_Parametrierung(Prueffall prueffall)
  {
  	DynamicObject ue = (DynamicObject)TestTools.getDynObjAusMenge(m_connection, m_anlage, "UrsachenEinheiten", m_pidUe);

  	SystemObject anzeige = m_dataModel.getObject(m_pidAnzeige);
  	
  	Data atgParam = erzeugeAtgParameterStauBeleg(prueffall);
  	Data atgEm = erzeugeAtgEinzelMassnahme(erzeugeMassnahmenAnforderung(anzeige));
  	Data atgUe = erzeugeAtgUrsachenEinheit();
  	Data atgMq = erzeugeAtgMqZuordnung();
  	
		try
		{
			parametriereDynObjUrsachenEinheit(ue, atgParam, atgEm, atgUe, atgMq);
		}
		catch (Exception e)
		{
			fail ("Ursacheneinheit konnte nicht parametriert werden");
		}

  }
  
  /**
   * In dieser Methode wird der Testfall 13.8 (1) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Zuerst werden die entsprechenden Daten eingespielt, nach einer kurzen Pause wird die Methode
   * StarteBerechnung des Algorithmus ausgefhrt und auf das Ergebnis gewartet. Nach dem der Status
   * empfangen wurde, wird das Ergebnis berprft.
   */
  private void prueffall_13_8_Test_1()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;
		
		int qB = 2400;
		int vKfz = 46;
		int bFs1 = 30;
		int bFs2 = 30;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}
    
		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 1)
				{
					fail("Test 1 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 0)
				{
					fail("Test 1 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}
				
//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (status)
//			{
//				fail ("Test 1 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }
  

  /**
   * In dieser Methode wird der Testfall 13.8 (2) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Zuerst werden die entsprechenden Daten eingespielt, nach einer kurzen Pause wird die Methode
   * StarteBerechnung des Algorithmus ausgefhrt und auf das Ergebnis gewartet. Nach dem der Status
   * empfangen wurde, wird das Ergebnis berprft.
   */
  private void prueffall_13_8_Test_2()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;

		int qB = 2400;
		int vKfz = 44;
		int bFs1 = 40;
		int bFs2 = 40;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}

		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 1)
				{
					fail("Test 2 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 1)
				{
					fail("Test 2 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}

//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (status)
//			{
//				fail ("Test 2 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }

  /**
   * In dieser Methode wird der Testfall 13.8 (2) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Dieser Test entspricht dem Test 13.8 (2). Aufgrund der Parameternderung ist aber das Ergebnis
   * zu 13.8 unterschiedlich.
   */
  private void prueffall_13_9_Test_2()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;

		int qB = 2400;
		int vKfz = 44;
		int bFs1 = 40;
		int bFs2 = 40;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}

		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 0)
				{
					fail("Test 2 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 1)
				{
					fail("Test 2 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}

//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (!status)
//			{
//				fail ("Test 2 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }

  /**
   * In dieser Methode wird der Testfall 13.8 (3) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Zuerst werden die entsprechenden Daten eingespielt, nach einer kurzen Pause wird die Methode
   * StarteBerechnung des Algorithmus ausgefhrt und auf das Ergebnis gewartet. Nach dem der Status
   * empfangen wurde, wird das Ergebnis berprft.
   */
  private void prueffall_13_8_Test_3()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;

		int qB = 2400;
		int vKfz = 44;
		int bFs1 = 51;
		int bFs2 = 36;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}

		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 0)
				{
					fail("Test 3 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 1)
				{
					fail("Test 3 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}

//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (!status)
//			{
//				fail ("Test 3 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }
	
  /**
   * In dieser Methode wird der Testfall 13.8 (4) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Zuerst werden die entsprechenden Daten eingespielt, nach einer kurzen Pause wird die Methode
   * StarteBerechnung des Algorithmus ausgefhrt und auf das Ergebnis gewartet. Nach dem der Status
   * empfangen wurde, wird das Ergebnis berprft.
   */
  private void prueffall_13_8_Test_4()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;

		int qB = 2400;
		int vKfz = 30;
		int bFs1 = 34;
		int bFs2 = 51;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}

		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 0)
				{
					fail("Test 4 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 1)
				{
					fail("Test 4 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}

//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (!status)
//			{
//				fail ("Test 4 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }

  /**
   * In dieser Methode wird der Testfall 13.8 (5) entsprechend der Prfspezifikation durchgefhrt.<p>
   * Zuerst werden die entsprechenden Daten eingespielt, nach einer kurzen Pause wird die Methode
   * StarteBerechnung des Algorithmus ausgefhrt und auf das Ergebnis gewartet. Nach dem der Status
   * empfangen wurde, wird das Ergebnis berprft.
   */
  private void prueffall_13_8_Test_5()
  {
		m_datenErhalten = false;
		m_analyseMqErhalten = false;

		int qB = 2400;
		int vKfz = 44;
		int bFs1 = 34;
		int bFs2 = 34;
						
		try
		{
			Data verkehrsdatenMq = erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(-1, vKfz, qB);
			DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"), m_dataModel.getAspect("asp.prognoseNormal"));

			for (int i = 0; i < m_messquerschnitte.size(); i++)
			{
				SenderOhneStatusRueckmeldung.source(m_connection, m_messquerschnitte.get(i), dd, verkehrsdatenMq);				
			}

			dd = new DataDescription(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"), m_dataModel.getAspect("asp.analyse"));

			if (m_fahrstreifen != null)
			{
				Data verkehrsdatenFs = null;

				for (int i = 0; i < m_fahrstreifen.size(); i++)
				{
					if (i == 0)
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs1);
					}
					else
					{
						verkehrsdatenFs = erzeugeAtgVerkehrsDatenKurzZeitFs(-1, -1, -1, -1,-1, -1, -1, bFs2);						
					}
					
					SenderOhneStatusRueckmeldung.source(m_connection, m_fahrstreifen.get(i), dd, verkehrsdatenFs);
				}
			}
		}
		catch (SenderException e)
		{
			e.printStackTrace();
		}

		m_connection.sleep(2000);
		
		m_alg.starteBerechnung();
		
    try
		{
    	synchronized (m_objekt)
			{
    		m_objekt.wait(10000);				
			}
		}
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}

		if (m_staukriteriumErhalten)
		{
			if (m_staukriterium != null)
			{
				if (m_staukriterium.getStaukriterium1().getZStau() == 1)
				{
					fail("Test 5 -> Einschaltkriterium nicht korrekt");					
				}
				
				if (m_staukriterium.getStaukriterium1().getZNichtStau() == 0)
				{
					fail("Test 5 -> Ausschaltkriterium nicht korrekt");					
				}
			}
		}
    
//		if (m_datenErhalten)
//		{
//			boolean status = bestimmeStatusEinzelsituationVorstufe();
//			System.out.println("Status " + status);
//			if (!status)
//			{
//				fail ("Test 5 -> Status der Einzelsituationvorstufe nicht korrekt");				
//			}
//		}
  }

	/* (non-Javadoc)
	 * @see de.bsvrz.ste.algorithmusrahmen.algorithmen.lib.INeueDatenListener#neueDaten(de.bsvrz.dav.daf.main.ResultData)
	 */
	@Override
	public void neueDaten(ResultData rdata)
	{
		System.out.println("StauTest.neueDaten() EinzelsituationVorstufe " + rdata.getObject().getPid());
		
		m_datenErhalten = true;
		m_DatensatzEinzelsituationVorstufe = rdata;
		
		synchronized (m_objekt)
		{
			m_objekt.notify();					
		}
	}
  
  /**
   * Erzeugt eine Liste mit Fahrstreifen fr die bergebene Liste der Messquerschnitte.
   * 
   * @param mqs Liste mit Messquerschnitten.
   * @return Liste mit Fahrstreifenobjekte.
   */
  private static List<SystemObject> bildeListeFahrstreifen(List<SystemObject> mqs)
	{
		if (mqs != null)
		{
			List<SystemObject> listeFs = new ArrayList<SystemObject>();
			
			for (int i = 0; i < mqs.size(); i++)
			{
				listeFs.addAll(bestimmeFahrstreifenMq(mqs.get(i)));
			}

			return listeFs;
		}
		return null;
	}
  
  /**
   * Bestimmt die Fahrstreifen des bergebenen Messquerschnitts.
   * 
   * @param mq Messquerschnitt.
   * @return Liste der Fahrstreifenobjekte.
   */
  private static List<SystemObject> bestimmeFahrstreifenMq(SystemObject mq)
	{
		if (mq != null)
		{			
				ConfigurationObject coObj = (ConfigurationObject)mq;
				return coObj.getNonMutableSet("FahrStreifen").getElements();
		}
		return null;
	}

	/**
	 * Bestimmt den aktuellen Zustand der Einzelsituationvorstufe des empfangenen Datensatzes.
	 * 
	 * @return true wenn Einzelsituationvorstufe wahr, ansonsten false.
	 */
	private boolean bestimmeStatusEinzelsituationVorstufe()
	{
		if (m_DatensatzEinzelsituationVorstufe != null)
		{
			if (m_DatensatzEinzelsituationVorstufe.hasData())
			{				
				Data data = m_DatensatzEinzelsituationVorstufe.getData();
				
				return data.getScaledValue("Status").getValueText().equals("Ja");
			}
		}
		
		return false;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaEinzelMassnahme</code>
	 * und gibt ihn zurck.
	 * 
	 * @param massnahmenanforderung Daten der Massnahmeanforderung.
	 * @return Datensatz <code>atg.sswSbaEinzelMassnahme</code>.
	 */
	private Data erzeugeAtgEinzelMassnahme(Massnahmenanforderung massnahmenanforderung)
	{
		if (massnahmenanforderung != null)
		{				
			Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.sswSbaEinzelMassnahme"));

			TestTools.fuelleAtgEinzelMassnahme(massnahmenanforderung, dataNeu);
			
			return dataNeu;
		}
		
		return null;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUrsachenEinheit</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.sswSbaUrsachenEinheit</code>.
	 */
	private Data erzeugeAtgUrsachenEinheit()
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.sswSbaUrsachenEinheit"));
		
		TestTools.fuelleAtgUrsachenEinheit(dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeMqZuordnung</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.sswSbaUeMqZuordnungt</code>.
	 */
  private Data erzeugeAtgMqZuordnung()
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.sswSbaUeMqZuordnung"));

		List<SystemObject> mqs = new ArrayList<SystemObject>();
		mqs.add(m_dataModel.getObject(m_pidMessQuerschnitt));
		
		TestTools.fuelleAtgMqZuordnung(mqs, dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.verkehrsDatenKurzZeitMq</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.verkehrsDatenKurzZeitMq</code>.
	 */
  private Data erzeugeAtgVerkehrsDatenKurzZeitMq(int qkfz, int vkfz, int qb, int alkw)
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitMq"));
		
		TestTools.fuelleAtgVerkehrsDatenKurzZeitMq(qkfz, vkfz, qb, alkw, dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.verkehrsDatenKurzZeitIntervall</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.verkehrsDatenKurzZeitIntervall</code>.
	 */
  private Data erzeugeAtgVerkehrsDatenKurzZeitIntervall(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz)
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitIntervall"));
		
		TestTools.fuelleAtgVerkehrsDatenKurzZeitIntervall(qkfz, vkfz, qlkw, vlkw, qpkw, vpkw, skfz, dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.verkehrsDatenKurzZeitFs</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.verkehrsDatenKurzZeitFs</code>.
	 */
  private Data erzeugeAtgVerkehrsDatenKurzZeitFs(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz, int b)
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitFs"));
		
		TestTools.fuelleAtgVerkehrsDatenKurzZeitFs(qkfz, vkfz, qlkw, vlkw, qpkw, vpkw, skfz, b, dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.verkehrsDatenKurzZeitTrendExtraPolationMq</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.verkehrsDatenKurzZeitTrendExtraPolationMq</code>.
	 */
  private Data erzeugeAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(int qkfz, int vkfz, int qb)
	{
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.verkehrsDatenKurzZeitTrendExtraPolationMq"));
		
		TestTools.fuelleAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(qkfz, vkfz, -1, qb, -1, -1, dataNeu);
		
		return dataNeu;
	}

	/**
	 * Diese Methode erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeStauBeleg</code>
	 * und gibt ihn zurck.
	 * 
	 * @return Datensatz <code>atg.sswSbaUeStauBeleg</code>.
	 */
  private Data erzeugeAtgParameterStauBeleg(Prueffall prueffall)
	{
		DataDescription dd = new DataDescription(m_dataModel.getAttributeGroup("atg.sswSbaUeStauBeleg"), m_dataModel.getAspect("asp.parameterSoll"));
  	DynamicObject ue = (DynamicObject)TestTools.getDynObjAusMenge(m_connection, m_anlage, "UrsachenEinheiten", m_pidUe);

		// Aktuelle Parameter holen
		ResultData rdata = m_connection.getData(ue, dd, 1000);
		
		// Wert setzen
		ParameterStauBeleg parameter = new ParameterStauBeleg(rdata);
		
		if (prueffall.equals(Prueffall.PRF1))
		{
			parameter.getParameterFahrstreifen(0).setBStauEin(50);
			parameter.getParameterFahrstreifen(0).setBStauAus(35);
			parameter.getParameterFahrstreifen(0).setVStauEin(45);

			parameter.getParameterFahrstreifen(1).setBStauEin(50);
			parameter.getParameterFahrstreifen(1).setBStauAus(35);
			parameter.getParameterFahrstreifen(1).setVStauEin(45);

			parameter.getParameterFahrstreifen(2).setBStauEin(50);
			parameter.getParameterFahrstreifen(2).setBStauAus(35);
			parameter.getParameterFahrstreifen(2).setVStauEin(45);
		}
		else
		{
			parameter.getParameterFahrstreifen(0).setBStauEin(35);
			parameter.getParameterFahrstreifen(0).setBStauAus(70);
			parameter.getParameterFahrstreifen(0).setVStauEin(55);

			parameter.getParameterFahrstreifen(1).setBStauEin(35);
			parameter.getParameterFahrstreifen(1).setBStauAus(70);
			parameter.getParameterFahrstreifen(1).setVStauEin(55);

			parameter.getParameterFahrstreifen(2).setBStauEin(50);
			parameter.getParameterFahrstreifen(2).setBStauAus(35);
			parameter.getParameterFahrstreifen(2).setVStauEin(45);
		}
		
		return parameter.erzeugeDatensatz((ClientDavConnection)m_connection);
	}

  /**
   * Methode erzeugt eine Manahmenanforderung mit der fr eine Anzeige ein bestimmter WVZ-Inhalt fr einen bestimmten
   * Schaltgrund angefordert wird
   * @param anzeige Anzeige die geschaltet werden soll
   * @return erzeugte Manahmenanforderung
   */
  private Massnahmenanforderung erzeugeMassnahmenAnforderung(SystemObject anzeige)
  {
    Massnahmenanforderung ma = new Massnahmenanforderung ();
    Vector<EinzelMassnahmeAlternative> einzelMassnahmeAlternative = new Vector<EinzelMassnahmeAlternative>();
    ma.setEinzelMassnahmeAlternative(einzelMassnahmeAlternative);
    
    EinzelMassnahmeAlternative alternative = new EinzelMassnahmeAlternative();
    einzelMassnahmeAlternative.add(alternative);
    
    Vector<AnzeigenDatensatz> datenSaetze = new Vector<AnzeigenDatensatz>();
    alternative.setEinzelMassnahmeAlternative(datenSaetze);
        
    AnzeigenDatensatz datensatz = new AnzeigenDatensatz();
    datenSaetze.add(datensatz);
    
		Data dataNeu = m_connection.createData(m_dataModel.getAttributeGroup("atg.sswSbaMassnahmenAnforderung"));
		dataNeu.getArray("EinzelMassnahmeAlternative").setLength(1);
		dataNeu.getArray("EinzelMassnahmeAlternative").getItem(0).getArray("AnzeigenDatenstze").setLength(1);
		Data dataWvzInhalt = dataNeu.getArray("EinzelMassnahmeAlternative").getItem(0).getArray("AnzeigenDatenstze").getItem(0).getItem("WVZInhalt"); 

		SystemObject anzeigeInhalt = m_dataModel.getObject("bw.uz.B27.streckenBeeinflussungsAnlage.wvzInhalt.tlsGefahrenstelle");
		
		// WVZInhalt
		dataWvzInhalt.getReferenceValue("AnzeigeInhalt").setSystemObject(anzeigeInhalt);
		dataWvzInhalt.getScaledValue("Blinken").setText("Nein");
		dataWvzInhalt.getScaledValue("Blinktakt").set(-1);
		dataWvzInhalt.getArray("GrafikDarstellungen").setLength(0);
		dataWvzInhalt.getReferenceValue("Wechseltext").setText("undefiniert");
    
    datensatz.setAnzeige(anzeige);
    datensatz.setAnzeigeInhalt(anzeigeInhalt);
    datensatz.setAbsolutNotwendig(false);
    datensatz.setNotwendig(false);
    datensatz.setPrioritt(-1);
    datensatz.setVerschiebbarNachfolger(0);
    datensatz.setVerschiebbarVorgnger(0);
    datensatz.setWvzInhalt(dataWvzInhalt);
    
    return ma;
  }
	/**
	 * Diese Methode parametriert das bergebene Objekt mit den bergebenen Datenstze.
	 * Wird <code>null</code> bergeben wird die entsprechende Attributgruppe nicht
	 * parametriert.
	 * 
	 * @param ue Dyn. Objekt Ursacheneinheit.
	 * @param atgSp Datensatz <code>atg.sswSbaUeStauBeleg</code>.
	 * @param atgEm Datensatz <code>atg.sswSbaEinzelMassnahme</code>.
	 * @param atgUe Datensatz <code>atg.sswSbaUrsachenEinheit</code>.
	 * @param atgmq Datensatz <code>atg.sswSbaUeMqZuordnung</code>.
	 */
	private void parametriereDynObjUrsachenEinheit(DynamicObject ue, Data atgParam, Data atgEm, Data atgUe, Data atgMq)
	{
		if (ue != null)
		{
			System.out.println("Ursacheneinheit " + ue + " parametrieren");
			
			Aspect asp = m_dataModel.getAspect("asp.parameterVorgabe");

      if (atgParam != null)
      {
				try
				{
					AttributeGroup atg = m_dataModel.getAttributeGroup("atg.sswSbaUeStauBeleg");
					DataDescription dd = new DataDescription(atg, asp);

					SimpleSenderMitWartenAufParametrierung.sendWait(m_connection, ue, dd, atgParam, 60000);
				}
				catch (SenderException e)
				{
					e.printStackTrace();
				} // Sende als Sender
      }
      
      if (atgEm != null)
      {
				try
				{
					AttributeGroup atg = m_dataModel.getAttributeGroup("atg.sswSbaEinzelMassnahme");
					DataDescription dd = new DataDescription(atg, asp);

					SimpleSenderMitWartenAufParametrierung.sendWait(m_connection, ue, dd, atgEm, 60000);
				}
				catch (SenderException e)
				{
					e.printStackTrace();
				} // Sende als Sender
      }
      
      if (atgUe != null)
      {
				try
				{
					AttributeGroup atg = m_dataModel.getAttributeGroup("atg.sswSbaUrsachenEinheit");
					DataDescription dd = new DataDescription(atg, asp);

					SimpleSenderMitWartenAufParametrierung.sendWait(m_connection, ue, dd, atgUe, 60000);
				}
				catch (SenderException e)
				{
					e.printStackTrace();
				} // Sende als Sender
      }

      if (atgMq != null)
      {
				try
				{
					AttributeGroup atg = m_dataModel.getAttributeGroup("atg.sswSbaUeMqZuordnung");
					DataDescription dd = new DataDescription(atg, asp);

					SimpleSenderMitWartenAufParametrierung.sendWait(m_connection, ue, dd, atgMq, 60000);
				}
				catch (SenderException e)
				{
					e.printStackTrace();
				} // Sende als Sender
      }

		}			
	}

	/* (non-Javadoc)
	 * @see de.bsvrz.ste.algorithmusrahmen.algorithmen.lib.INeueDatenListener#neueDatenSituationAnalyseMq(de.bsvrz.ste.algorithmusrahmen.algorithmen.lib.SituationAnalyseMq)
	 */
	@Override
	public void neueDatenSituationAnalyseMq(SituationAnalyseMq analyse)
	{
		System.out.println("StauTest.neueDatenSituationAnalyseMq()" + analyse);

		m_analyseMq = analyse;
		m_analyseMqErhalten = true;
		
		synchronized (m_objekt2)
		{
			m_objekt2.notify();					
		}
	}

	/* (non-Javadoc)
	 * @see de.bsvrz.ste.algorithmusrahmen.algorithmen.lib.INeueDatenListener#neueDatenStaukriterium(de.bsvrz.ste.algorithmusrahmen.algorithmen.lib.StaukriteriumErgebnis)
	 */
	@Override
	public void neueDatenStaukriterium(StaukriteriumErgebnis staukriterium)
	{
		
		System.out.println("StauTest.neueDatenStaukriterium() " + staukriterium);
		
		m_staukriterium = staukriterium;
		m_staukriteriumErhalten = true;		

		synchronized (m_objekt2)
		{
			m_objekt2.notify();					
		}
	}
}
